Do not use reserved words as keyword names. The following names are reserved and
cannot be used:

`IF`, `ELSE IF`, `ELSE`, `FOR`, `END`, `WHILE`, `CONTINUE`, `RETURN`,
`TRY`, `EXCEPT`, `FINALLY`

Rename the keyword to something else. If you intended to use a control structure,
verify that it's properly formatted and capitalized.
